@@ -11,14 +11,29 @@ class ConfigIngredientForm(forms.ModelForm):
     class Meta:
         model = models.ConfigIngredient
 
-    def clean_value(self):
-        value = self.cleaned_data.get('value', None)
-        if value:
+    class Media:
+        js = (
+            'js/jquery.textarea.min.js',
+        )
+
+
+    def clean_config_yaml(self):
+        config_yaml = self.cleaned_data.get('config_yaml', None)
+        if config_yaml:
             try:
-                yaml.safe_load(value)
+                yaml.safe_load(config_yaml)
             except:
                 raise forms.ValidationError("Invalid YAML")
-        return value
+        return config_yaml
+
+    def clean_env_yaml(self):
+        env_yaml = self.cleaned_data.get('env_yaml', None)
+        if env_yaml:
+            try:
+                yaml.safe_load(env_yaml)
+            except:
+                raise forms.ValidationError("Invalid YAML")
+        return env_yaml
 
 
 class BuildForm(forms.Form):
@@ -108,14 +123,28 @@ class SwarmForm(forms.Form):
     balancer = forms.ChoiceField(choices=[], label='Balancer', required=False,
                                  help_text=balancer_help)
 
+    ci_help = "Ctrl-click to select multiple, and unselect."
+    config_ingredients = forms.ModelMultipleChoiceField(
+        queryset=models.ConfigIngredient.objects.all(), required=False,
+        help_text=ci_help)
+
     def __init__(self, data, *args, **kwargs):
+        if 'instance' in kwargs:
+            # We get the 'initial' keyword argument or initialize it
+            # as a dict if it didn't exist.
+            initial = kwargs.setdefault('initial', {})
+            # The widget for a ModelMultipleChoiceField expects
+            # a list of primary key for the selected data.
+            initial['config_ingredients'] = [
+                c.pk for c in kwargs['instance'].configingredient_set.all()]
+
         super(SwarmForm, self).__init__(data, *args, **kwargs)
         self.fields['squad_id'].choices = [(s.id, s) for s in
                                             models.Squad.objects.all()]
         self.fields['app_id'].choices = [(a.id, a) for a in
                                             models.App.objects.all()]
-        self.fields['balancer'].choices = [('', '-------')] + [(b, b) for b in
-                                                               settings.BALANCERS]
+        self.fields['balancer'].choices = [('', '-------')] + [
+            (b, b) for b in settings.BALANCERS]
 
     def clean(self):
         data = super(SwarmForm, self).clean()
@@ -124,6 +153,13 @@ class SwarmForm(forms.Form):
                                         'specify a balancer')
         return data
 
+    def save(self):
+        instance = super(SwarmForm, self).save()
+        instance.configingredient_set.clear()
+        for ing in self.cleaned_data['config_ingredients']:
+            instance.configingredient_set.add(ing)
+        return instance
+
     class Media:
         js = (
             'js/jquery.textarea.min.js',
